%global firefox_app_id \{ec8030f7-c20a-464f-9b0e-13a3a9e97384\}
%global seamonkey_app_id \{92650c4d-4b8e-4d2a-b7eb-24ecf4f6b63a\}
%global thunderbird_app_id \{3550f703-e582-4d05-9a08-453d09bdfdc6\}

# Extension ID for this package, from install.rdf
%global extension_id \{aa84ce40-4253-11da-8cd6-0800200c9a66\}
%global firebreath_version 1.5.2

Name:           esteid-browser-plugin
Version:        1.3.3
Release:        3%{?dist}
Summary:        Estonian ID card digital signing browser plugin

# The source files from esteid-browser-plugin and Firebreath are compiled
# together to the shared object npesteid.so.
# Firebreath is dual-licensed [BSD or LGPLv2+], esteid-browser-plugin is LGPLv2+.
# The resulting npesteid.so binary is: LGPLv2+.
#
# The files in mozilla-esteid subpackage are all from esteid-browser-plugin
# tarball and are LGPLv2+.
License:        LGPLv2+
URL:            http://code.google.com/p/esteid/

# Firebreath is a 'framework' for building browser plugins and with a separate
# upstream: http://www.firebreath.org. By design, projects using Firebreath are
# supposed to be built within Firebreath's build system, so we need the tarball
# for building.
Source0:        http://firebreath.googlecode.com/files/firebreath-%{firebreath_version}.tar.bz2
# ... and the source code for esteid-browser-plugin itself:
Source1:        http://esteid.googlecode.com/files/%{name}-%{version}.tar.bz2

# Fix the build with boost 1.50, backported from upstream SVN
Patch0:         0001-esteid-browser-plugin-Use-boost-filesystem-v3.patch

BuildRequires:  boost-devel
BuildRequires:  cmake
BuildRequires:  gettext
BuildRequires:  gtkmm24-devel
BuildRequires:  openssl-devel
BuildRequires:  smartcardpp-devel
BuildRequires:  zip
Requires:       mozilla-filesystem%{?_isa}

%description
esteid-browser-plugin is cross-browser plugin exposing Estonian eID card's
digital signing functions in JavaScript. Digital signing is a common operation
on Estonian electronic bank sites. To protect privacy, the plugin only allows
access for web sites in an editable whitelist.


%package -n mozilla-esteid
Summary:        Estonian ID card Mozilla extension
BuildArch:      noarch
Requires:       esteid-browser-plugin = %{version}-%{release}
Requires:       %{_sysconfdir}/digidocpp/certs
Requires:       opensc
Obsoletes:      thunderbird-esteid < 1.2.1

%description -n mozilla-esteid
esteid-browser-plugin is cross-browser plugin exposing Estonian eID card's
digital signing functions in JavaScript. Digital signing is a common operation
on Estonian electronic bank sites. To protect privacy, the plugin only allows
access for web sites in an editable whitelist.

This package contains the Estonian ID card digital signing extension for
Firefox and Thunderbird.


%prep
# Extract firebreath
%setup -q -n firebreath-%{firebreath_version}

# Extract esteid-browser-plugin into firebreath's projects/ subdir
mkdir -p projects
pushd projects
tar -xf %{S:1}
popd

# Remove bundled libraries
rm -rf src/3rdParty/boost
rm -rf src/libs

# Patch to fix the build with boost 1.50
pushd projects/esteid-browser-plugin-%{version}
%patch0 -p1 -b .boost_filesystem
popd


%build
export CFLAGS="$RPM_OPT_FLAGS -fno-strict-aliasing"
export CXXFLAGS="$CFLAGS"

mkdir -p %{_target_platform}
pushd %{_target_platform}
%{cmake} -DWITH_SYSTEM_BOOST:BOOL=YES ..
popd

make %{?_smp_mflags} -C %{_target_platform}


%install
make install DESTDIR=$RPM_BUILD_ROOT -C %{_target_platform}

# Install the extension files
unzip %{_target_platform}/projects/esteid/esteid-*.xpi \
      -d $RPM_BUILD_ROOT%{_datadir}/mozilla-esteid

# Register the extension for Firefox and Thunderbird
for app_id in %{firefox_app_id} %{seamonkey_app_id} %{thunderbird_app_id} ; do
    mkdir -p $RPM_BUILD_ROOT%{_datadir}/mozilla/extensions/$app_id
    pushd $RPM_BUILD_ROOT%{_datadir}/mozilla/extensions/$app_id
        ln -s %{_datadir}/mozilla-esteid %{extension_id}
    popd
done

%find_lang esteid-browser-plugin


%files -f esteid-browser-plugin.lang
%doc projects/%{name}-%{version}/{AUTHORS,COPYING,NEWS}
%config(noreplace) %{_sysconfdir}/esteid-browser-plugin.conf
%{_libdir}/mozilla/plugins/npesteid.so
%{_datadir}/%{name}/

%files -n mozilla-esteid
%{_datadir}/mozilla-esteid/
%{_datadir}/mozilla/extensions/%{firefox_app_id}/
%{_datadir}/mozilla/extensions/%{seamonkey_app_id}/
%{_datadir}/mozilla/extensions/%{thunderbird_app_id}/


%changelog
* Mon Aug 06 2012 Kalev Lember <kalevlember@gmail.com> - 1.3.3-3
- Rebuild for boost 1.50, and backport a patch for Boost Filesystem v3

* Thu Jul 19 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.3.3-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Tue Apr 17 2012 Kalev Lember <kalevlember@gmail.com> - 1.3.3-1
- Update to 1.3.3
- Include the NEWS file as %%doc

* Tue Feb 28 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.3.2-4
- Rebuilt for c++ ABI breakage

* Fri Jan 13 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.3.2-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Mon Nov 21 2011 Kalev Lember <kalevlember@gmail.com> - 1.3.2-2
- Rebuilt for boost 1.48

* Fri Oct 14 2011 Kalev Lember <kalevlember@gmail.com> - 1.3.2-1
- Update to 1.3.2
- Register the extension in SeaMonkey

* Wed Oct 12 2011 Kalev Lember <kalevlember@gmail.com> - 1.3.1-1
- Update to 1.3.1

* Mon Aug 22 2011 Kalev Lember <kalevlember@gmail.com> - 1.3.0-2
- Added a comment explaining the multiple licensing breakdown and the reason
  for split tarballs (#732419)
- Remove bundled libraries in prep

* Thu Aug 18 2011 Kalev Lember <kalevlember@gmail.com> - 1.3.0-1
- Update to 1.3.0

* Wed Aug 10 2011 Kalev Lember <kalevlember@gmail.com> - 1.2.1-1
- Update to 1.2.1

* Thu Dec 02 2010 Kalev Lember <kalev@smartlink.ee> - 1.2.0-0.1.svn3765
- Install esteid-browser-plugin.conf

* Thu Jun 24 2010 Kalev Lember <kalev@smartlink.ee> - 1.0.0-0.7.svn2771
- build against system boost instead of using bundled copy
- Dropped genproject.cmake hacks

* Mon Mar 29 2010 Kalev Lember <kalev@smartlink.ee> - 1.0.0-0.6.svn2665
- Removed scriplets which are no longer needed now that thunderbird
  owns its extension dir (RHBZ#532132)
- Added AUTHORS and COPYING docs
- Cleaned up nightly build changelog entries

* Mon Feb 15 2010 Kalev Lember <kalev@smartlink.ee> - 1.0.0-0.1.svn2586
- Initial RPM release.
